package com.sun.corba.se.impl.orbutil;

import java.util.Arrays;

public abstract class ObjectWriter
{
    protected StringBuffer result;
    
    public static ObjectWriter make(boolean b, int n, int n2) {
        if (b) {
            return new IndentingObjectWriter(n, n2);
        }
        return new ObjectWriter.SimpleObjectWriter();
    }
    
    public abstract void startObject(Object p0);
    
    public abstract void startElement();
    
    public abstract void endElement();
    
    public abstract void endObject(String p0);
    
    public abstract void endObject();
    
    @Override
    public String toString() {
        return this.result.toString();
    }
    
    public void append(boolean b) {
        this.result.append(b);
    }
    
    public void append(char c) {
        this.result.append(c);
    }
    
    public void append(short i) {
        this.result.append((int)i);
    }
    
    public void append(int i) {
        this.result.append(i);
    }
    
    public void append(long lng) {
        this.result.append(lng);
    }
    
    public void append(float f) {
        this.result.append(f);
    }
    
    public void append(double d) {
        this.result.append(d);
    }
    
    public void append(String str) {
        this.result.append(str);
    }
    
    protected ObjectWriter() {
        this.result = new StringBuffer();
    }
    
    protected void appendObjectHeader(Object o) {
        this.result.append(o.getClass().getName());
        this.result.append("<");
        this.result.append(System.identityHashCode(o));
        this.result.append(">");
        Class<Object> componentType = o.getClass().getComponentType();
        if (componentType != null) {
            this.result.append("[");
            if (componentType == Boolean.TYPE) {
                this.result.append(((boolean[])(boolean[])o).length);
                this.result.append("]");
            }
            else if (componentType == Byte.TYPE) {
                this.result.append(((byte[])(byte[])o).length);
                this.result.append("]");
            }
            else if (componentType == Short.TYPE) {
                this.result.append(((short[])(short[])o).length);
                this.result.append("]");
            }
            else if (componentType == Integer.TYPE) {
                this.result.append(((int[])(int[])o).length);
                this.result.append("]");
            }
            else if (componentType == Long.TYPE) {
                this.result.append(((long[])(long[])o).length);
                this.result.append("]");
            }
            else if (componentType == Character.TYPE) {
                this.result.append(((char[])(char[])o).length);
                this.result.append("]");
            }
            else if (componentType == Float.TYPE) {
                this.result.append(((float[])(float[])o).length);
                this.result.append("]");
            }
            else if (componentType == Double.TYPE) {
                this.result.append(((double[])(double[])o).length);
                this.result.append("]");
            }
            else {
                this.result.append(((Object[])(Object[])o).length);
                this.result.append("]");
            }
        }
        this.result.append("(");
    }
    
    private static class IndentingObjectWriter extends ObjectWriter
    {
        private int level;
        private int increment;
        
        public IndentingObjectWriter(int level, int increment) {
            this.level = level;
            this.increment = increment;
            this.startLine();
        }
        
        private void startLine() {
            char[] array = new char[this.level * this.increment];
            Arrays.fill(array, ' ');
            this.result.append(array);
        }
        
        @Override
        public void startObject(Object o) {
            this.appendObjectHeader(o);
            ++this.level;
        }
        
        @Override
        public void startElement() {
            this.result.append("\n");
            this.startLine();
        }
        
        @Override
        public void endElement() {
        }
        
        @Override
        public void endObject(String str) {
            --this.level;
            this.result.append(str);
            this.result.append(")");
        }
        
        @Override
        public void endObject() {
            --this.level;
            this.result.append("\n");
            this.startLine();
            this.result.append(")");
        }
    }
    
    private static class SimpleObjectWriter extends ObjectWriter
    {
        @Override
        public void startObject(Object o) {
            this.appendObjectHeader(o);
            this.result.append(" ");
        }
        
        @Override
        public void startElement() {
            this.result.append(" ");
        }
        
        @Override
        public void endObject(String str) {
            this.result.append(str);
            this.result.append(")");
        }
        
        @Override
        public void endElement() {
        }
        
        @Override
        public void endObject() {
            this.result.append(")");
        }
    }
}
